The MPL Reference Manual: BOOST_MPL_CFG_NO_HAS_XXX_TEMPLATE

Front Page / Macros / Configuration / BOOST_MPL_CFG_NO_HAS_XXX_TEMPLATE

# BOOST_MPL_CFG_NO_HAS_XXX_TEMPLATE

### Synopsis

    // #define BOOST_MPL_CFG_NO_HAS_XXX_TEMPLATE

### Description

`BOOST_MPL_CFG_NO_HAS_XXX_TEMPLATE` is a boolean configuration macro signaling availability of the BOOST_MPL_HAS_XXX_TEMPLATE_DEF / BOOST_MPL_HAS_XXX_TEMPLATE_NAMED_DEF introspection macros' functionality on a particular compiler.

### See also

Macros, Configuration, BOOST_MPL_HAS_XXX_TEMPLATE_DEF, BOOST_MPL_HAS_XXX_TEMPLATE_NAMED_DEF